@@ -26,6 +26,7 @@ from glue.iterutils import inorder, uniq
 from lal import PI, MTSUN_SI
 from lalinspiral import CreateSBankWorkspaceCache
 from lalinspiral.sbank.psds import get_neighborhood_ASD, get_neighborhood_PSD, get_PSD, get_neighborhood_df_fmax
+from . import waveforms
 
 class lazy_nhoods(object):
     __slots__ = ("seq", "nhood_param")
@@ -41,7 +42,7 @@ class lazy_nhoods(object):
 
 class Bank(object):
 
-    def __init__(self, noise_model, flow, use_metric=False, cache_waveforms=False, nhood_size=1.0, nhood_param="tau0", coarse_match_df=None, iterative_match_df_max=None, fhigh_max=None):
+    def __init__(self, noise_model, flow, use_metric=False, cache_waveforms=False, nhood_size=1.0, nhood_param="tau0", coarse_match_df=None, iterative_match_df_max=None, fhigh_max=None, optimize_flow=None, flow_column=None):
 
         self.noise_model = noise_model
         self.flow = flow
@@ -49,6 +50,8 @@ class Bank(object):
         self.cache_waveforms = cache_waveforms
         self.coarse_match_df = coarse_match_df
         self.iterative_match_df_max = iterative_match_df_max
+        self.optimize_flow = optimize_flow
+        self.flow_column = flow_column
 
         if self.coarse_match_df and self.iterative_match_df_max and self.coarse_match_df < self.iterative_match_df_max:
             # If this case occurs coarse_match_df offers no improvement, turn off
@@ -60,7 +63,7 @@ class Bank(object):
             self.fhigh_max = fhigh_max
 
         self.nhood_size = nhood_size
-        self.nhood_param = "_" + nhood_param
+        self.nhood_param = nhood_param
 
         self._templates = []
         self._nmatch = 0
@@ -107,6 +110,23 @@ class Bank(object):
         self._templates.extend(newtmplts)
         self._templates.sort(key=attrgetter(self.nhood_param))
 
+    def add_from_hdf(self, hdf_fp):
+        num_points = len(hdf_fp['mass1'])
+        newtmplts=[]
+        for idx in xrange(num_points):
+            if not idx % 100000:
+                tmp = {}
+                end_idx = min(idx+100000, num_points)
+                for name in hdf_fp:
+                    tmp[name] = hdf_fp[name][idx:end_idx]
+            c_idx = idx % 100000
+            approx = tmp['approximant'][c_idx]
+            tmplt_class = waveforms.waveforms[approx]
+            newtmplts.append(tmplt_class.from_dict(tmp, c_idx, self))
+            newtmplts[-1].is_seed_point=True
+        self._templates.extend(newtmplts)
+        self._templates.sort(key=attrgetter(self.nhood_param))
+
     @classmethod
     def from_sngls(cls, sngls, tmplt_class, *args, **kwargs):
         bank = cls(*args, **kwargs)
@@ -183,11 +203,6 @@ class Bank(object):
                     # FIXME: This could be dealt with dynamically??
                     raise ValueError(err_msg)
 
-                # record match and template params for highest match
-                if match > max_match:
-                    max_match = match
-                    template = tmplt
-
                 if (1 - match) > 0.05 + (1 - min_match):
                     continue
 
@@ -202,11 +217,6 @@ class Bank(object):
                     # FIXME: This could be dealt with dynamically??
                     raise ValueError(err_msg)
 
-                # record match and template params for highest match
-                if match > max_match:
-                    max_match = match
-                    template = tmplt
-
                 # if the result is a really bad match, trust it isn't
                 # misrepresenting a good match
                 if (1 - match) > 0.05 + (1 - min_match):
@@ -223,6 +233,11 @@ class Bank(object):
             if match > min_match:
                 return (match, tmplt)
 
+            # record match and template params for highest match
+            if match > max_match:
+                max_match = match
+                template = tmplt
+
         return (max_match, template)
 
     def max_match(self, proposal):
