@@ -541,8 +541,8 @@ def aligned_spin_param_generator(flow, tmplt_class, bank, **kwargs):
         spin1 = (chis*mtot - mass2*spin2)/mass1
 
         t = tmplt_class(mass1, mass2, spin1, spin2, bank=bank)
-        if (dur_min is not None and t._dur < dur_min) \
-                or (dur_max is not None and t._dur > dur_max):
+        if (dur_min is not None and t.dur < dur_min) \
+                or (dur_max is not None and t.dur > dur_max):
             continue
         yield t
 
