@@ -731,7 +731,7 @@ LALFindChirpBCVCFilterSegment (
         }
 
         /* record the data that we need for the clustering algorithm */
-        thisEvent->end_time.gpsSeconds = j;
+        thisEvent->end.gpsSeconds = j;
         thisEvent->snr   = rhosqConstraint;
         thisEvent->alpha = alphaC;
         /* use some variable which are not filled in BCV filterinf to keep
@@ -743,11 +743,11 @@ LALFindChirpBCVCFilterSegment (
         thisEvent->tau5  = alphaU;
       }
       else if ( !(params->clusterMethod == FindChirpClustering_none) &&
-          j <= thisEvent->end_time.gpsSeconds + deltaEventIndex &&
+          j <= thisEvent->end.gpsSeconds + deltaEventIndex &&
           rhosqConstraint > thisEvent->snr )
       {
         /* if this is the same event, update the maximum */
-        thisEvent->end_time.gpsSeconds = j;
+        thisEvent->end.gpsSeconds = j;
         thisEvent->snr = rhosqConstraint;
         thisEvent->alpha = alphaC;
         thisEvent->tau0  = V0;
@@ -756,23 +756,23 @@ LALFindChirpBCVCFilterSegment (
         thisEvent->tau4  = rhosqUnconstraint;
         thisEvent->tau5  = alphaU;
       }
-      else if (j > thisEvent->end_time.gpsSeconds + deltaEventIndex ||
+      else if (j > thisEvent->end.gpsSeconds + deltaEventIndex ||
           params->clusterMethod == FindChirpClustering_none )
       {
         /* clean up this event */
         SnglInspiralTable *lastEvent;
         INT8               timeNS;
-        INT4               timeIndex = thisEvent->end_time.gpsSeconds;
+        INT4               timeIndex = thisEvent->end.gpsSeconds;
 
         /* set the event LIGO GPS time of the event */
         timeNS = 1000000000L *
           (INT8) (input->segment->data->epoch.gpsSeconds);
         timeNS += (INT8) (input->segment->data->epoch.gpsNanoSeconds);
         timeNS += (INT8) (1e9 * timeIndex * deltaT);
-        thisEvent->end_time.gpsSeconds = (INT4) (timeNS/1000000000L);
-        thisEvent->end_time.gpsNanoSeconds = (INT4) (timeNS%1000000000L);
+        thisEvent->end.gpsSeconds = (INT4) (timeNS/1000000000L);
+        thisEvent->end.gpsNanoSeconds = (INT4) (timeNS%1000000000L);
         thisEvent->end_time_gmst = fmod(XLALGreenwichMeanSiderealTime(
-            &(thisEvent->end_time)), LAL_TWOPI) * 24.0 / LAL_TWOPI;	/* hours */
+            &(thisEvent->end)), LAL_TWOPI) * 24.0 / LAL_TWOPI;	/* hours */
         ASSERT( !XLAL_IS_REAL8_FAIL_NAN(thisEvent->end_time_gmst), status, LAL_FAIL_ERR, LAL_FAIL_MSG );
 
         /* set the impuse time for the event */
@@ -783,7 +783,7 @@ LALFindChirpBCVCFilterSegment (
             2 * sizeof(CHAR) );
         strncpy( thisEvent->channel, input->segment->data->name + 3,
             (LALNameLength - 3) * sizeof(CHAR) );
-        thisEvent->impulse_time = thisEvent->end_time;
+        thisEvent->impulse_time = thisEvent->end;
 
         /* copy the template into the event */
         thisEvent->psi0   = (REAL4) input->fcTmplt->tmplt.psi0;
@@ -829,7 +829,7 @@ LALFindChirpBCVCFilterSegment (
         }
 
         /* stick minimal data into the event */
-        thisEvent->end_time.gpsSeconds = j;
+        thisEvent->end.gpsSeconds = j;
         thisEvent->snr = rhosqConstraint;
         thisEvent->alpha = alphaC;
         thisEvent->tau0  = V0;
@@ -852,17 +852,17 @@ LALFindChirpBCVCFilterSegment (
  if ( thisEvent )
   {
     INT8           timeNS;
-    INT4           timeIndex = thisEvent->end_time.gpsSeconds;
+    INT4           timeIndex = thisEvent->end.gpsSeconds;
 
     /* set the event LIGO GPS time of the event */
     timeNS = 1000000000L *
       (INT8) (input->segment->data->epoch.gpsSeconds);
     timeNS += (INT8) (input->segment->data->epoch.gpsNanoSeconds);
     timeNS += (INT8) (1e9 * timeIndex * deltaT);
-    thisEvent->end_time.gpsSeconds = (INT4) (timeNS/1000000000L);
-    thisEvent->end_time.gpsNanoSeconds = (INT4) (timeNS%1000000000L);
+    thisEvent->end.gpsSeconds = (INT4) (timeNS/1000000000L);
+    thisEvent->end.gpsNanoSeconds = (INT4) (timeNS%1000000000L);
     thisEvent->end_time_gmst = fmod(XLALGreenwichMeanSiderealTime(
-        &(thisEvent->end_time)), LAL_TWOPI) * 24.0 / LAL_TWOPI;	/* hours */
+        &(thisEvent->end)), LAL_TWOPI) * 24.0 / LAL_TWOPI;	/* hours */
     ASSERT( !XLAL_IS_REAL8_FAIL_NAN(thisEvent->end_time_gmst), status, LAL_FAIL_ERR, LAL_FAIL_MSG );
 
     /* set the impuse time for the event */
@@ -873,7 +873,7 @@ LALFindChirpBCVCFilterSegment (
         2 * sizeof(CHAR) );
     strncpy( thisEvent->channel, input->segment->data->name + 3,
         (LALNameLength - 3) * sizeof(CHAR) );
-    thisEvent->impulse_time = thisEvent->end_time;
+    thisEvent->impulse_time = thisEvent->end;
 
 
     /* copy the template into the event */
