@@ -1,5 +1,6 @@
 /*
- * LALInspiralVCSInfo.h - LALInspiral VCS Information Header
+ * Copyright (C) 2014, 2016 Karl Wette
+ * Copyright (C) 2009-2013 Adam Mercer
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,9 +16,10 @@
  * along with with program; see the file COPYING. If not, write to the
  * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
  * MA 02111-1307 USA
- *
- * Copyright (C) 2009-2013 Adam Mercer
- * Copyright (C) 2014 Karl Wette
+ */
+
+/*
+ * LALInspiralVCSInfo.h - LALInspiral VCS Information Header
  */
 
 /** \cond DONT_DOXYGEN */
@@ -33,37 +35,19 @@
 extern "C" {
 #endif
 
-/* VCS information defines */
-#define LALINSPIRAL_NAME "LALInspiral"
-#define LALINSPIRAL_VCS_ID "d2ce60837be0672f33dcba397d5822aecf221839"
-#define LALINSPIRAL_VCS_DATE "2016-10-10 17:31:35 +0000"
+/* VCS information */
+#define LALINSPIRAL_VCS_ID "a00b854511244fc757da2d6f5a689699236e1327"
+#define LALINSPIRAL_VCS_DATE "2017-02-6 18:16:01 +0000"
 #define LALINSPIRAL_VCS_BRANCH "None"
-#define LALINSPIRAL_VCS_TAG "lalinspiral-v1.7.6"
+#define LALINSPIRAL_VCS_TAG "lalinspiral-v1.7.7"
 #define LALINSPIRAL_VCS_AUTHOR "Adam Mercer <adam.mercer@ligo.org>"
 #define LALINSPIRAL_VCS_COMMITTER "Adam Mercer <adam.mercer@ligo.org>"
+#define LALINSPIRAL_VCS_CLEAN "CLEAN"
 #define LALINSPIRAL_VCS_STATUS "CLEAN: All modifications committed"
 
-/* Identable VCS information defines */
-#define LALINSPIRAL_VCS_IDENT_ID "$" "LALInspiralId: d2ce60837be0672f33dcba397d5822aecf221839 " "$"
-#define LALINSPIRAL_VCS_IDENT_DATE "$" "LALInspiralDate: 2016-10-10 17:31:35 +0000 " "$"
-#define LALINSPIRAL_VCS_IDENT_BRANCH "$" "LALInspiralBranch: None " "$"
-#define LALINSPIRAL_VCS_IDENT_TAG "$" "LALInspiralTag: lalinspiral-v1.7.6 " "$"
-#define LALINSPIRAL_VCS_IDENT_AUTHOR "$" "LALInspiralAuthor: Adam Mercer <adam.mercer@ligo.org> " "$"
-#define LALINSPIRAL_VCS_IDENT_COMMITTER "$" "LALInspiralCommitter: Adam Mercer <adam.mercer@ligo.org> " "$"
-#define LALINSPIRAL_VCS_IDENT_STATUS "$" "LALInspiralStatus: CLEAN: All modifications committed " "$"
-
-/* Header VCS information structure */
-static const LALVCSInfo lalInspiralVCSInfoHeader = { \
-  LALINSPIRAL_NAME, \
-  LALINSPIRAL_VERSION, \
-  LALINSPIRAL_VCS_ID, \
-  LALINSPIRAL_VCS_DATE, \
-  LALINSPIRAL_VCS_BRANCH, \
-  LALINSPIRAL_VCS_TAG, \
-  LALINSPIRAL_VCS_AUTHOR, \
-  LALINSPIRAL_VCS_COMMITTER, \
-  LALINSPIRAL_VCS_STATUS \
-};
+/* VCS header/library mismatch link check function */
+#define LALINSPIRAL_VCS_LINK_CHECK LALINSPIRAL_CLEAN_a00b854511244fc757da2d6f5a689699236e1327_VCS_HEADER_LIBRARY_MISMATCH
+void LALINSPIRAL_VCS_LINK_CHECK(void);
 
 #ifdef __cplusplus
 }
@@ -72,7 +56,3 @@ static const LALVCSInfo lalInspiralVCSInfoHeader = { \
 #endif /* _LALINSPIRALVCSINFOHEADER_H */
 
 /** \endcond */
-
-/*
- * vim: tw=0 ts=2 et
- */
