@@ -126,6 +126,7 @@
 #include <lal/GeneratePPNInspiral.h>
 #include <lal/LALSQTPNWaveformInterface.h>
 #include <lal/TimeSeries.h>
+#include <lal/LALDict.h>
 
 /**
  * Generate the plus and cross polarizations for a waveform
@@ -162,11 +163,8 @@ int XLALSimInspiralChooseWaveformFromSimInspiral(
    REAL8 f_ref = 0.;
    REAL8 r = thisRow->distance * LAL_PC_SI * 1e6;
    REAL8 i = thisRow->inclination;
-   REAL8 lambda1 = 0.; /* FIXME:0 turns these terms off, these should be obtained by some other means */
-   REAL8 lambda2 = 0.; /* FIXME:0 turns these terms off, these should be obtained by some other means */
-   LALSimInspiralWaveformFlags *waveFlags=XLALSimInspiralCreateWaveformFlags();
-   LALSimInspiralTestGRParam *nonGRparams = NULL;
-   int amplitudeO = thisRow->amp_order;
+   LALDict *LALpars=XLALCreateDict();
+   XLALSimInspiralWaveformParamsInsertPNAmplitudeOrder(LALpars, thisRow->amp_order);
 
    /* get approximant */
    approximant = XLALSimInspiralGetApproximantFromString(thisRow->waveform);
@@ -177,6 +175,7 @@ int XLALSimInspiralChooseWaveformFromSimInspiral(
    order = XLALSimInspiralGetPNOrderFromString(thisRow->waveform);
    if ( (int) order == XLAL_FAILURE)
       XLAL_ERROR(XLAL_EFUNC);
+   XLALSimInspiralWaveformParamsInsertPNPhaseOrder(LALpars, order);
 
    /* get taper option */
    taper = XLALSimInspiralGetTaperFromString(thisRow->taper);
@@ -188,17 +187,19 @@ int XLALSimInspiralChooseWaveformFromSimInspiral(
    switch(approximant)
    {
       case NumRelNinja2:
-         if (XLALNRInjectionFromSimInspiral(hplus, hcross, thisRow, deltaT) == XLAL_FAILURE)
+         if (XLALNRInjectionFromSimInspiral(hplus, hcross, thisRow, deltaT) == XLAL_FAILURE) {
+            XLALDestroyDict(LALpars);
             XLAL_ERROR(XLAL_EFUNC);
+         }
+         XLALDestroyDict(LALpars);
          break;
 
       default:
-         ret = XLALSimInspiralChooseTDWaveform(hplus, hcross, phi0, deltaT,
-               m1, m2, S1x, S1y, S1z, S2x, S2y, S2z, f_min, f_ref, r, i,
-               lambda1, lambda2, waveFlags, nonGRparams, amplitudeO,
-               order, approximant);
-         XLALSimInspiralDestroyWaveformFlags(waveFlags);
-         XLALSimInspiralDestroyTestGRParam(nonGRparams);
+         ret = XLALSimInspiralChooseTDWaveform(hplus, hcross, m1, m2,
+					       S1x, S1y, S1z, S2x, S2y, S2z, r, i,
+					       phi0, 0., 0., 0., deltaT, f_min, f_ref,
+					       LALpars, approximant);
+         XLALDestroyDict(LALpars);
          if( ret == XLAL_FAILURE )
             XLAL_ERROR(XLAL_EFUNC);
    }
@@ -242,14 +243,10 @@ int XLALInspiralTDWaveformFromSimInspiral(
    REAL8 S2z = thisRow->spin2z;
    REAL8 f_min = thisRow->f_lower;
    REAL8 f_ref = 0.;
-   REAL8 r = thisRow->distance * LAL_PC_SI * 1e6;
-   REAL8 i = thisRow->inclination;
-   REAL8 lambda1 = 0.; /* FIXME:0 turns these terms off, these should be obtained by some other means */
-   REAL8 lambda2 = 0.; /* FIXME:0 turns these terms off, these should be obtained by some other means */
-   REAL8 z = 0.; /* FIXME:0 means zero redshift, this should be obtained by some other means */
-   LALSimInspiralWaveformFlags *waveFlags=XLALSimInspiralCreateWaveformFlags();
-   LALSimInspiralTestGRParam *nonGRparams = NULL;
-   int amplitudeO = thisRow->amp_order;
+   REAL8 distance = thisRow->distance * LAL_PC_SI * 1e6;
+   REAL8 inclination = thisRow->inclination;
+   LALDict *params = XLALCreateDict();
+   XLALSimInspiralWaveformParamsInsertPNAmplitudeOrder(params, thisRow->amp_order);
 
    /* get approximant */
    approximant = XLALSimInspiralGetApproximantFromString(thisRow->waveform);
@@ -260,14 +257,15 @@ int XLALInspiralTDWaveformFromSimInspiral(
    order = XLALSimInspiralGetPNOrderFromString(thisRow->waveform);
    if ( (int) order == XLAL_FAILURE)
       XLAL_ERROR(XLAL_EFUNC);
+   XLALSimInspiralWaveformParamsInsertPNPhaseOrder(params, order);
 
    /* note: the condition waveform already does tapering... ignore any request to do so get taper option */
    /* taper = XLALGetTaperFromString(thisRow->taper); */
 
    /* generate +,x waveforms */
-   ret = XLALSimInspiralTD(hplus, hcross, phi0, deltaT, m1, m2, S1x, S1y, S1z, S2x, S2y, S2z, f_min, f_ref, r, z, i, lambda1, lambda2, waveFlags, nonGRparams, amplitudeO, order, approximant);
-   XLALSimInspiralDestroyWaveformFlags(waveFlags);
-   XLALSimInspiralDestroyTestGRParam(nonGRparams);
+   ret = XLALSimInspiralTD(hplus, hcross, m1, m2, S1x, S1y, S1z, S2x, S2y, S2z, distance, inclination, phi0, 0.0, 0.0, 0.0, deltaT, f_min, f_ref, params, approximant);
+
+   XLALDestroyDict(params);
    if( ret == XLAL_FAILURE )
      XLAL_ERROR(XLAL_EFUNC);
 
@@ -304,20 +302,18 @@ XLALSimInspiralChooseWaveformFromInspiralTemplate(
   /* Value of 'distance' fed to lalsim is conventional to obtain a correct template norm */
   REAL8 r = params->distance;
   REAL8 i = params->inclination;
-  REAL8 lambda1 = 0.; /* FIXME:0 turns these terms off, these should be obtained by some other means */
-  REAL8 lambda2 = 0.; /* FIXME:0 turns these terms off, these should be obtained by some other means */
-  LALSimInspiralWaveformFlags *waveFlags = XLALSimInspiralCreateWaveformFlags();
-  LALSimInspiralTestGRParam *nonGRparams = NULL;
-  LALPNOrder amplitudeO = params->ampOrder;
-  LALPNOrder order = params->order;
+  LALDict *LALpars=XLALCreateDict();
+  XLALSimInspiralWaveformParamsInsertPNAmplitudeOrder(LALpars,params->ampOrder);
+  XLALSimInspiralWaveformParamsInsertPNPhaseOrder(LALpars,params->order);
   Approximant approximant = params->approximant;
 
   /* generate +,x waveforms */
-  ret = XLALSimInspiralChooseTDWaveform(hplus, hcross, phi0, deltaT, m1, m2,
-            S1x, S1y, S1z, S2x, S2y, S2z, f_min, f_ref, r, i, lambda1, lambda2,
-            waveFlags, nonGRparams, amplitudeO, order, approximant);
-  XLALSimInspiralDestroyWaveformFlags(waveFlags);
-  XLALSimInspiralDestroyTestGRParam(nonGRparams);
+  ret = XLALSimInspiralChooseTDWaveform(hplus, hcross, m1, m2,
+					S1x, S1y, S1z, S2x, S2y, S2z, r, i,
+					phi0, 0., 0., 0., deltaT, f_min, f_ref,
+					LALpars, approximant);
+  XLALDestroyDict(LALpars);
+
   if( ret == XLAL_FAILURE)
     XLAL_ERROR(XLAL_EFUNC);
 
