@@ -238,11 +238,6 @@ if ( ( (val) <= (lower) ) || ( (val) > (upper) ) )                   \
 }                                                                    \
 while (0)
 
-/* A global pointer for debugging. */
-#ifndef NDEBUG
-char *lalWatch;
-#endif
-
 /* A function to convert INT8 nanoseconds to LIGOTimeGPS. */
 void
 I8ToLIGOTimeGPS( LIGOTimeGPS *output, INT8 input );
